# A28 Changelog

## Unreleased (2021-05-19)

#### New Features

* move actions into separate files
#### Refactorings

* remove erroneous empty lines
#### Others

* remove additional empty lines in imports
* remove local version string in version
* remove local version string in version

Full set of changes: [`v0.1.1...258c33a`](https://gitlab.com/area28/app/devkit/compare/v0.1.1...258c33a)

## v0.1.1 (2021-05-18)

#### New Features

* add configuration management
#### Fixes

* fix PEP8 two lines before class
* change doc directory to docs ([#jvb43q](https://gitlab.com/area28/app/devkit/issues/jvb43q))
* ensure line endings are consistent ([#jvau4k](https://gitlab.com/area28/app/devkit/issues/jvau4k))
* remove Python 3.10 tests in GitLab [#jv4pu5](https://gitlab.com/area28/app/devkit/issues/jv4pu5)
#### Others

* add dynamic versioning
* ignore .a28 files when exporting
* add better ci tests
* fix poetry configs in-project command
* add tests for exists and clean actions

Full set of changes: [`v0.1.0...v0.1.1`](https://gitlab.com/area28/app/devkit/compare/v0.1.0...v0.1.1)

## v0.1.0 (2021-05-12)

#### New Features

* create output directory if it doesn't already exist
* (build): Initial version of the development kit for external developers.
#### Others

* ignore any .a28 packages created
